console.log("Auth routes loaded");
const express = require("express");
const bcrypt = require('bcryptjs');
const jwt = require("jsonwebtoken");
const db = require("../config/db");
const util = require("util"); // ✅ ใช้ util.promisify() เพื่อรองรับ async/await

const router = express.Router();

// 🔹 แปลง db.query เป็น async function
const query = util.promisify(db.query).bind(db);

// 🔹 Register
router.post("/register", async (req, res) => {
    const { username, password } = req.body;

    try {
        const hashedPassword = await bcrypt.hash(password, 10);
        await query(
            "INSERT INTO users (username, password_hash) VALUES (?, ?)",
            [username, hashedPassword]
        );
        res.status(201).json({ message: "User registered!" });
    } catch (error) {
        res.status(500).json({ error: error.message });
    }
});

// 🔹 Login (แก้ให้รองรับ async/await อย่างถูกต้อง)
router.post("/login", async (req, res) => {
    const { username, password } = req.body;

    try {
        const results = await query("SELECT * FROM users WHERE username = ?", [username]);
        if (results.length === 0) return res.status(401).json({ error: "Invalid credentials" });

        const user = results[0];
        const isMatch = await bcrypt.compare(password, user.password_hash);

        if (!isMatch) return res.status(401).json({ error: "Invalid credentials" });

        // ✅ ใช้ process.env.JWT_SECRET แทน "mysecret"
        const token = jwt.sign({ id: user.id, username: user.username }, process.env.JWT_SECRET, { expiresIn: "1h" });

        res.json({ token });
    } catch (error) {
        res.status(500).json({ error: error.message });
    }
});

module.exports = router;
